package com.ruoyi.app.mapper;

import com.ruoyi.app.domain.AppPmsOrderOut;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-14
 */
public interface AppPmsOrderOutMapper
{
    /**
     * 查询【请填写功能名称】
     *
     * @param recordId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppPmsOrderOut selectAppPmsOrderOutByListId(String recordId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appPmsOrderOut 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppPmsOrderOut> selectAppPmsOrderOutList(AppPmsOrderOut appPmsOrderOut);

    /**
     * 新增【请填写功能名称】
     *
     * @param appPmsOrderOut 【请填写功能名称】
     * @return 结果
     */
    public int insertAppPmsOrderOut(AppPmsOrderOut appPmsOrderOut);

    /**
     * 修改【请填写功能名称】
     *
     * @param appPmsOrderOut 【请填写功能名称】
     * @return 结果
     */
    public int updateAppPmsOrderOut(AppPmsOrderOut appPmsOrderOut);

    /**
     * 删除【请填写功能名称】
     *
     * @param recordId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppPmsOrderOutByListId(String recordId);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAppPmsOrderOutByListIds(String[] recordIds);
    public int deleteAppPmsOrderOutByOrderId(AppPmsOrderOut appPmsOrderOut);

    int updatePickNum(AppPmsOrderOut appPmsOrderOut);
}
