package com.ruoyi.web.controller.app;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.app.domain.AppPmsOrderIn;
import com.ruoyi.app.domain.AppPmsOrderOut;
import com.ruoyi.app.service.IAppPmsOrderOutService;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.web.controller.section.EnhanceDataList;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-15
 */
@RestController
@RequestMapping("/app/pmsOrderOut")
public class AppPmsOrderOutController extends BaseController
{
    @Autowired
    private IAppPmsOrderOutService appPmsOrderOutService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:out:list')")
    @GetMapping("/list")
    @EnhanceDataList(entityType = AppPmsOrderOut.class)
    public TableDataInfo list(AppPmsOrderOut appPmsOrderOut)
    {
        startPage();
        List<AppPmsOrderOut> list = appPmsOrderOutService.selectAppPmsOrderOutList(appPmsOrderOut);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:out:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppPmsOrderOut appPmsOrderOut)
    {
        List<AppPmsOrderOut> list = appPmsOrderOutService.selectAppPmsOrderOutList(appPmsOrderOut);
        ExcelUtil<AppPmsOrderOut> util = new ExcelUtil<AppPmsOrderOut>(AppPmsOrderOut.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:out:query')")
    @GetMapping(value = "/{listId}")
    public AjaxResult getInfo(@PathVariable("listId") String listId)
    {
        return success(appPmsOrderOutService.selectAppPmsOrderOutByListId(listId));
    }

    /**
     * 新增【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    @Anonymous
    public AjaxResult add(@RequestBody AppPmsOrderOut appPmsOrderOut)
    {
        return toAjax(appPmsOrderOutService.insertAppPmsOrderOut(appPmsOrderOut));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:out:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppPmsOrderOut appPmsOrderOut)
    {
        return toAjax(appPmsOrderOutService.updateAppPmsOrderOut(appPmsOrderOut));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:out:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{listIds}")
    public AjaxResult remove(@PathVariable String[] listIds)
    {
        return toAjax(appPmsOrderOutService.deleteAppPmsOrderOutByListIds(listIds));
    }
}
